Module socialization.ccs.wrapped_goddess_db_agent
=================================================

Classes
-------

`WrappedGoddessDBAgent(path)`
:   

    ### Methods

    `add_whistle_msg(self, channel_id, msg, recipients)`
    :

    `get_channel_user_list(self, channel_id)`
    :

    `get_whistle_recipients(self, channel_id, msg)`
    :

    `init_dog_whistle(self, channel_id)`
    :

    `init_user_id_list(self, channel_id, user_ids)`
    :

    `join_channel(self, channel_id, user_id)`
    :

    `leave_channel(self, channel_id, user_id)`
    :